/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: ApacheRFC1867Parser.cpp 2696 2007-11-18 14:46:40Z svn $
 *****************************************************************************/

#include "ApacheRFC1867Parser.h"

#include "Environment.h"

#include "SourceInfo.h"
#define TEMPLATE_INSTANTIATION
#include "MultipartMessageParser.cpp"
#include "RFC1867Parser.cpp"

#include "BasicFileWriter.cpp"
#include "MmapFileWriter.cpp"

SOURCE_INFO_ADD("$Id: ApacheRFC1867Parser.cpp 2696 2007-11-18 14:46:40Z svn $");

template class MultipartMessageParser<ApacheRequestReader>;
template class RFC1867Parser<ApacheRequestReader>;

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
